@@ -14,7 +14,7 @@ LANGUAGE_NAME = 1
 
 def get_real_fieldname(field, lang=None):
     if lang is None:
-       lang = get_language()
+       lang = get_language().split('-')[0] # both 'en-US' and 'en' -> 'en'
     return str('%s_%s' % (field, lang))
 
 
